==> maxdb-source-7_6_00_09.tgz: V76_00_09/MaxDB_ORG/sys/src/SAPDB/ServerTasks/SrvTasks_JobJoinInvSelector.cpp <==
/*!
  @file        SrvTasks_JobJoinInvSelector.cpp
  @author      UweH
  @ingroup     ServerTasks
  @brief       This is the implementation of SrvTasks_JobJoinInvSelector
  @since       2004-06-08

\if EMIT_LICENCE
  copyright:    Copyright (c) 2001-2004 SAP AG


    ========== licence begin  GPL
    Copyright (c) 2001-2004 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end
\endif
*/
#include "ServerTasks/SrvTasks_JobJoinInvSelector.hpp"
#include "KernelCommon/Kernel_Trace.hpp"
#include "Transaction/Trans_Context.hpp"

void SrvTasks_JobJoinInvSelector::Execute ()
{
    Trans_Context &trans = GetTransContext();

    Join_InvSelectByServer (trans, m_Input);

    if ( trans.OldTrans().trError_gg00 != e_ok )
    {
        AppendContextInfo(__CONTEXT__, trans.ErrorList(), "Error occured");
        Kernel_AppendBasisError (trans.OldTrans().trError_gg00,trans.ErrorList(),"Error occured");
        m_Result = trans.OldTrans().trError_gg00;
    }
}

==> maxdb-source-7_6_00_37.tgz: V76_00_37/MaxDB_ORG/sys/src/SAPDB/ServerTasks/SrvTasks_JobJoinInvSelector.cpp <==
/*!
  @file        SrvTasks_JobJoinInvSelector.cpp
  @author      UweH
  @ingroup     ServerTasks
  @brief       This is the implementation of SrvTasks_JobJoinInvSelector
  @since       2004-06-08

\if EMIT_LICENCE
  copyright:    Copyright (c) 2001-2005 SAP AG


    ========== licence begin  GPL
    Copyright (c) 2001-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

\endif
*/
#include "ServerTasks/SrvTasks_JobJoinInvSelector.hpp"
#include "KernelCommon/Kernel_Trace.hpp"
#include "Transaction/Trans_Context.hpp"

SrvTasks_Job::Result
SrvTasks_JobJoinInvSelector::ExecuteIntern (Trans_Context &trans)
{
    tgg00_BasisError &trError = trans.OldTrans().trError_gg00;
    
    Join_InvSelectByServer (trans, m_Input);

    if ( trError != e_ok )
    {
        AppendContextInfo(__CONTEXT__, trans.ErrorList(), "Error occured");
        Kernel_AppendBasisError (trError,trans.ErrorList(),"Error occured");
    }
    return trError;
}
